package uniklu.games.spaceship;

import javax.imageio.ImageIO;
import java.awt.image.BufferedImage;
import java.awt.*;
import java.awt.geom.AffineTransform;
import java.io.IOException;

/**
 * Created by IntelliJ IDEA.
 * User: install
 * Date: 07.04.2008
 * Time: 17:10:43
 * To change this template use File | Settings | File Templates.
 */
public class ShipSprite {
    private static BufferedImage[] animationSequence;
    private int animationState = 0;
    // gives the index in sequence at given state:
    private int x, y, movement = 4;
    private double currentMovement = 0d, acceleration = 0.7;
    private boolean moveLeft = false, moveRight = false, jump = false;
    private double zoom = 1d;
    private static int width;
    private static int height;
    private double jumpHeight = 0, maxJumpHeight = 3;
    private Color shadowColor = new Color(0, 0, 0, 128);

    public static void initAnimation() {
        try {
            BufferedImage strip = ImageIO.read(ExplosionSprite.class.getResource("gfx/ship.png"));
            animationSequence = SpriteUtils.createSprites(strip, 3);
            width = animationSequence[0].getWidth();
            height = animationSequence[0].getHeight();
        } catch (IOException e) {
            e.printStackTrace();
        }
    }

    public void drawSprite(Graphics2D g2) {
        if (moveLeft && !moveRight || moveRight && !moveLeft) {
            // accelerate on button pressed:
            if (moveRight) currentMovement += acceleration;
            else if (moveLeft) currentMovement -= acceleration;
        } else { // decelerate
            if (currentMovement < 0) currentMovement += acceleration;
            else if (currentMovement > 0) currentMovement -= acceleration;
            if (Math.abs(currentMovement) < 1) currentMovement = 0;
        }
        // actually move the ship:
        long moveDiscrete = Math.round(currentMovement);
        x += moveDiscrete;
        // determine acceleration state:
        if (moveDiscrete == 0) animationState = 0;
        else if (Math.abs(moveDiscrete) >= 4) animationState = 2; // fast
        else animationState = 1; // accellerating

        // implement jumping ...
        if (jump) {
            jumpHeight += 0.3;
            if (jumpHeight > maxJumpHeight) jump = false;
        } else if (jumpHeight > 0) {
            jumpHeight -= 0.3;
            if (jumpHeight < 0) jumpHeight = 0;
        }


        double w = width * zoom * (jumpHeight / maxJumpHeight + 1);
        double h = height * zoom * (jumpHeight / maxJumpHeight + 1);

        g2.setColor(shadowColor);
        g2.fillOval((int) (x - (w + jumpHeight * 5) / 2) + ((int) jumpHeight * 5), (int) (y - (h + ((int) jumpHeight * 5)) / 2),
                (int) w + ((int) jumpHeight * 5), (int) h + ((int) jumpHeight * 5));
        g2.drawImage(animationSequence[animationState],
                (int) (x - w / 2), (int) (y - h / 2), (int) w, (int) h,
                null);
    }

    public void setPosition(int x, int y) {
        this.x = x;
        this.y = y;
    }

    public void setMoveLeft(boolean moveLeft) {
        this.moveLeft = moveLeft;
    }

    public void setMoveRight(boolean moveRight) {
        this.moveRight = moveRight;
    }

    public double getZoom() {
        return zoom;
    }

    public void setZoom(double zoom) {
        this.zoom = zoom;
    }

    public RocketSprite fire() {
        RocketSprite rocket = new RocketSprite();
        rocket.setPosition(x, y + 5);
        return rocket;
    }

    public void jump() {
        jump = true;
    }
}
